@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-
 Copyright (C) 2009-2011 John Goerzen <jgoerzen@complete.org>
 
@@ -28,7 +29,9 @@ module Data.Convertible.Base( -- * The conversion process
                               prettyConvertError
                              )
 where
+#if !MIN_VERSION_mtl(2,3,0)
 import Control.Monad.Error
+#endif
 import Data.Typeable
 
 {- | The result of a safe conversion via 'safeConvert'. -}
@@ -61,7 +64,7 @@ instance Convertible a b => Convertible [a] [b] where
 an error with the conversion.  For a function that does not raise an exception
 in that case, see 'safeConvert'. -}
 convert :: Convertible a b => a -> b
-convert x = 
+convert x =
     case safeConvert x of
       Left e -> error (prettyConvertError e)
       Right r -> r
@@ -89,25 +92,27 @@ data ConvertError = ConvertError {
       convErrorMessage :: String}
                     deriving (Eq, Read, Show)
 
+#if !MIN_VERSION_mtl(2,3,0)
 instance Error ConvertError where
     strMsg x = ConvertError "(unknown)" "(unknown)" "(unknown)" x
+#endif
 
 convError' :: (Show a, Typeable a, Typeable b) =>
                String -> a -> b -> ConvertResult b
-convError' msg inpval retval = 
+convError' msg inpval retval =
      Left $ ConvertError {
              convSourceValue = show inpval,
              convSourceType = show . typeOf $ inpval,
              convDestType = show . typeOf $ retval,
              convErrorMessage = msg}
-    
+
 convError :: (Show a, Typeable a, Typeable b) =>
              String -> a -> ConvertResult b
-convError msg inpval = 
+convError msg inpval =
     convError' msg inpval undefined
-    
+
 prettyConvertError :: ConvertError -> String
 prettyConvertError (ConvertError sv st dt em) =
     "Convertible: error converting source data " ++ sv ++ " of type " ++ st
     ++ " to type " ++ dt ++ ": " ++ em
-    
+
